@@ -105,9 +105,10 @@ def test(session: nox.Session) -> None:
 @nox.session(python=["3.13"], default=False)
 def setup_dev(session: nox.Session) -> None:
     """Setup dev environment post project creation."""
+    _setup_venv(session)
     session.run("ruff", "check", ".", external=True)
     session.run("ruff", "format", ".", external=True)
-    session.run("uv", "run", "pre-commit", "install", external=True)
+    session.run("pre-commit", "install", external=True)
     with Path(".secrets.baseline").open("w", encoding="utf-8") as out:
         session.run("detect-secrets", "scan", stdout=out, external=True)
     session.run("git", "add", ".", external=True)
